Boost.Core
==========

Boost.Core, part of collection of the [Boost C++ Libraries](http://github.com/boostorg), is a collection of core utilities used by other Boost libraries.
The criteria for inclusion is that the utility component be:

* simple,
* used by other Boost libraries, and
* not dependent on any other Boost modules except Core itself, Config, Assert, Static Assert, or Predef.

### Directories

* **doc** - Documentation of the components
* **include** - Interface headers
* **test** - Unit tests

### More information

* [Documentation](http://boostorg.github.io/core)

### License

Distributed under the [Boost Software License, Version 1.0](http://boost.org/LICENSE_1_0.txt).
